The ``klio-core`` Package
=========================

.. image:: https://img.shields.io/pypi/v/klio-core?color=%2300aa55&label=klio-core
   :target: https://pypi.org/project/klio-core
   :alt: Latest version of klio-core on PyPI

.. image:: https://github.com/spotify/klio/workflows/klio-core%20unit%20tests/badge.svg
   :target: https://github.com/spotify/klio/actions?query=workflow%3A%22klio-core+unit+tests%22
   :alt: Status of klio-core unit tests

.. start-klio-core-intro

A library of common utilities, including the Klio `protobuf definitions <https://docs.klio.io/en/latest/userguide/pipeline/message.html>`_ and configuration parsing.

As the ``klio-core`` package is **not** meant to be installed directly, check out the `installation guide <https://docs.klio.io/en/latest/quickstart/installation.html>`_ for how to setup installation.
There is also the `user guide <https://docs.klio.io/en/latest/userguide/index.html>`_ and the `API documentation <https://docs.klio.io/en/latest/reference/core/index.html>`_ for more information.
